##  Seeing Complete Data in a Report
Sometimes, one or more Fact Sheets are not included in Reports due to missing data. Does this message look familiar?
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27425c567a441014ac37e9aa92757b41_LowRes.png)
Clicking on the Show list link will open a pop-up window providing a list of all Fact Sheets that are not included in the report due to missing data.
To ensure that all the Fact Sheets are included in a Report without any missing data, you must fill in the necessary attribute fields in the Fact Sheets. You may refer to the tables below. It gives you an overview of all standard Reports in SAP LeanIX and shows which Fact Sheet types, relations, and attribute fields are needed to complete them.
**Tip**
For better readability of the below matrix, [download the PDF version![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fd.dam.sap.com%2Fa%2FeKFjNak%2FRequired_info_Matrix_for_reporting.pdf%3Frc%3D10%26inline%3Dtrue%26doi%3DSAP1226589 "https://d.dam.sap.com/a/eKFjNak/Required_info_Matrix_for_reporting.pdf?rc=10&inline=true&doi=SAP1226589").
![\[Download\]\(https://leanix.box.com/s/1x002czrgqobn1h20zmj1288ky6nojui\) the above matrix in PDF form here](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27507ecf7a441014b3b8c34a65c3add0_LowRes.png)
Necessary Attributes To Be Filled In Fact Sheets To Ensure Inclusion of All Fact Sheets in Reports
